---
title: Loops
description: Loops API reference
---

# Loops

This module contains the loop implementations in `arc`. Loops can be used to call a function repeatedly with a given interval.

::: arc.utils.loops
